#ifndef FFTHANDLER_H
#define FFTHANDLER_H
#include "/usr/include/fftw3.h"
#include <QVector>
/**
 * @brief Permite el cálculo de FFT usando la librería FFTW
 */
class FFTHandler {
public:
    FFTHandler(int N);
    /**
     * @brief Calcula la FFT de un arreglo de datos y lo almacena en un arreglo interno
     * @param data puntero a datos a procesar
     * @return puntero a arreglo con los valores complejos de la FFT
     */
    double *computeFFT(short *data);
    /**
     * @brief Mutador para acceder a los puntos por defecto a calcular
     * @return número de puntos por defecto
     */
    int getPoints();
    /**
     * @brief Rellena un arreglo interno con los datos a procesar
     * @param data puntero a datos a procesar
     */

    void populate(short *data);
    /**
     * @brief Funcion a implementar
     * @param points puntos de FFT a cambiar
     */
    void changeFFTPoints(int points);
    /**
     * @brief (OBSOLETA, usada en dspmanager) Metodo que permite obtener peaks de un arreglo de datos
     * @param arr puntero a arreglo de datos a procesar
     * @param size tamaño del arreglo
     * @param threshold umbral de tolerancia de detección
     * @return arreglo de posiciones en muestras máximas
     */
    QVector <double> * getPeaks(double *arr, int size, int threshold);

private:
    int points;
    fftw_plan p;
    double *out_fft, *in_fft;
    QVector<double> peaks;

};

#endif /* FFTHANDLER_H */

