#ifndef DSPMANAGER_H
#define DSPMANAGER_H

#include <stdlib.h>
#include <math.h>

#define PI 3.14159

#define HAMMING 0
#define HANN 1
#define BLACKMAN 2
#define BLACKMAN_HARRIS 3
/**
 * @brief Herramientas de procesado de señales (ventanas, filtros, etc)
 */
class DSPManager
{
public:
    DSPManager(long int length);
    /**
     * @brief Aplica una ventana seleccionada y generada en la clase a un arreglo de datos
     * @param data puntero a datos a enventanar
     * @param window_flag flag que indica la ventana a usar
     */
    void applyWindow(short *data, short window_flag);
    /**
     * @brief Obtiene el valor máximo de una secuencia de muestras
     * @param t puntero a arreglo con las muestras
     * @param size tamaño del arreglo
     * @return posición de la muestra máxima
     */
    short getMaxima(double *t, int size);

private:
    double *hamming_window;
    double *hann_window;
    double *blackman_window;
    double *blackmanHarris_window;
    /**
     * @brief Genera una ventana Hamming para aplicar a una señal
     */
    void generateHammingWindow();
    /**
     * @brief Genera una ventana Hann para aplicar a una señal
     */
    void generateHannWindow();
    /**
     * @brief Genera una ventana Blackman para aplicar a una señal
     */
    void generateBlackmanWindow();
    /**
     * @brief Genera una ventana Blackman - Harris para aplicar a una señal
     */
    void generateBlackmanHarrisWindow();

    long int length;

};

#endif // DSPMANAGER_H
