#include "ui_tuner.h"
#include "micmanager.h"
#include "ffthandler.h"
#include "tuner.h"

#include <QRect>

int main(int argc, char **argv)
{

    /*
     *  Settings for the audio capture are directly related
     *  with the results of the FFT, so you need to be care-
     *  ful of the parameters. For example, the buffer size
     *  can affect directly on the processing time, because
     *  we use it to determine the number of points to com-
     *  pute the FFT. Despite the ear bandwidth, a good sam-
     *  ple rate can improve the fine tuning.
     */

    // The buffer image size is the buffer that the program
    // uses to display data to the screen. It can show as
    // spectre or time series.

    int buffer_image_size = 256;

    // The total buffer size purpose is to achieve the DCT
    // with a great precition. Due to large compute times,
    // the total buffe isnt able to show visual info

    int n = 4;
    int total_buffer_size = pow(2,n)*buffer_image_size;

    // Lower sample rates can perform computations more
    // quickly, but also can reduce drastically the data
    // display. Also, we need to take care about the ins-
    // trument bandwidth

    long int sample_rate = 8000;

    /*
     * MicManager class uses the ALSA library to have some
     * low-level control on the audio capture. However, the
     * purpose of the class is to give some high-level cus-
     * tomization of the capture process, avoiding higly and
     * unnecesary coding.
     */

    MicManager *mic = new MicManager(buffer_image_size, total_buffer_size, sample_rate);

    /*
     * FFTHandler class uses the FFTW C library to perform all
     * the computations that involve real-time signal spectre.
     * The library brings the fastest algorythm despite the num-
     * ber of points. However, it is not recommended to use num-
     * bers above 4096, in honor of time computing
     */

    FFTHandler *calcFFT = new FFTHandler(total_buffer_size);

    QApplication a(argc, argv);
    QRect screenDim = QApplication::desktop()->screenGeometry();
    int x = screenDim.width();
    int y = screenDim.height();
    QRect winDimensions(x/4,y/5,x/2,3*y/5);

    std::cout << "Welcome to AlHoTuner.\nYour screen resolution is " <<x<<"x"<<y;
    std::cout << ". Parsing at center of the screen\0";

    std::cout << screenDim.x() << std::endl;
    Tuner w(calcFFT, mic, winDimensions);
    w.show();
    return a.exec();

}

